# coding: utf-8

"""
    Katib

    Swagger description for Katib  # noqa: E501

    OpenAPI spec version: v1beta1-0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import kubeflow.katib
from kubeflow.katib.models.v1beta1_suggestion import V1beta1Suggestion  # noqa: E501
from kubeflow.katib.rest import ApiException


class TestV1beta1Suggestion(unittest.TestCase):
    """V1beta1Suggestion unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testV1beta1Suggestion(self):
        """Test V1beta1Suggestion"""
        # FIXME: construct object with mandatory attributes with example values
        # model = katib.models.v1beta1_suggestion.V1beta1Suggestion()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
